from django import forms
from django.contrib.auth.models import User
from .models import Request
from django.core.exceptions import ValidationError
import re
from django.contrib.auth import authenticate
from django.utils import timezone

class UserRegistrationForm(forms.Form):
    username = forms.CharField(max_length=150, required=True, label='Логин')
    password = forms.CharField(widget=forms.PasswordInput, required=True, label='Пароль')
    full_name = forms.CharField(max_length=255, required=True, label='ФИО')
    phone = forms.CharField(
        max_length=20,
        required=True,
        label='Телефон',
        widget=forms.TextInput(attrs={
            'placeholder': '+7(___)___-__-__',  # Плейсхолдер с маской
            'data-mask': '+7(000)000-00-00',    # Маска для ввода
            'oninput': 'this.value = this.value.replace(/[^0-9]/g, "")',  # Разрешаем только цифры
        }),
    )
    email = forms.EmailField(required=True, label='Электронная почта')

    def clean_username(self):
        username = self.cleaned_data.get('username')
        if User.objects.filter(username=username).exists():
            raise ValidationError("Этот логин уже занят.")
        return username

    def clean_password(self):
        password = self.cleaned_data.get('password')
        
        if len(password) < 6:
            raise ValidationError("Пароль должен содержать минимум 6 символов.")
        
        if not re.search(r'[A-Z]', password):
            raise ValidationError("Пароль должен содержать хотя бы одну заглавную букву.")

        if not re.search(r'[a-z]', password):
            raise ValidationError("Пароль должен содержать хотя бы одну строчную букву.")
        
        if not re.search(r'\d', password):
            raise ValidationError("Пароль должен содержать хотя бы одну цифру.")
        
        if not re.search(r'[!@#$%^&*(),.?":{}|<>]', password):
            raise ValidationError("Пароль должен содержать хотя бы один специальный символ.")
        
        return password

    def clean_full_name(self):
        full_name = self.cleaned_data.get('full_name')
        if not re.match(r'^[А-Яа-яЁё\s]+$', full_name):
            raise ValidationError("ФИО должно содержать только кириллицу и пробелы.")
        return full_name

    def clean_phone(self):
        phone = self.cleaned_data.get('phone')
        if not re.match(r'^\+7\(\d{3}\)-\d{3}-\d{2}-\d{2}$', phone):
            raise ValidationError("Телефон должен быть в формате +7(XXX)-XXX-XX-XX.")
        return phone

    class Meta:
        model = User
        fields = ['username', 'first_name', 'last_name', 'email', 'password']

class UserLoginForm(forms.Form):
    username = forms.CharField(max_length=150, required=True, label='Логин')
    password = forms.CharField(widget=forms.PasswordInput, required=True, label='Пароль')

    def clean(self):
        cleaned_data = super().clean()
        username = cleaned_data.get('username')
        password = cleaned_data.get('password')

        if username and password:
            user = authenticate(username=username, password=password)
            if user is None:
                raise forms.ValidationError("Неверный логин или пароль.")
            
class RequestForm(forms.ModelForm):
    other_service = forms.BooleanField(required=False, label='Иная услуга')
    other_service_description = forms.CharField(required=False, label='Описание иной услуги')

    class Meta:
        model = Request
        fields = ['service', 'address', 'contact_number', 'date_time', 'payment_type', 'other_service', 'other_service_description']
        widgets = {
            'date_time': forms.DateTimeInput(attrs={
                'type': 'datetime-local',  # Используем тип datetime-local для выбора даты и времени
                'min': timezone.now().strftime('%Y-%m-%dT%H:%M'),  # Устанавливаем минимальную дату на текущее время
            }),
            'contact_number': forms.TextInput(attrs={
                'placeholder': '+7(___)___-__-__',  # Плейсхолдер с маской
                'data-mask': '+7(000)000-00-00',  # Маска для ввода
                'oninput': 'this.value = this.value.replace(/[^0-9]/g, "")',  # Разрешаем только цифры
            }),
        }

    def clean(self):
        cleaned_data = super().clean()
        other_service = cleaned_data.get('other_service')
        other_service_description = cleaned_data.get('other_service_description')

        if other_service and not other_service_description:
            raise forms.ValidationError("Пожалуйста, укажите описание иной услуги.")

        return cleaned_data

    def clean_contact_number(self):
        contact_number = self.cleaned_data.get('contact_number')
        if not re.match(r'^\+7\(\d{3}\)-\d{3}-\d{2}-\d{2}$', contact_number):
            raise forms.ValidationError("Телефон должен быть в формате +7(XXX)-XXX-XX-XX.")
        return contact_number



import unittest
from Django_auths.module_auth import hello

class TestHelloFunction(unittest.TestCase):
    def test_hello(self):
        self.assertEqual(hello("World"), "Hello, World!")

if __name__ == '__main__':
    unittest.main()


# Generated by Django 5.1.6 on 2025-02-21 05:53

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Service',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('description', models.TextField(blank=True)),
            ],
        ),
        migrations.CreateModel(
            name='Request',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('address', models.CharField(max_length=255)),
                ('contact_number', models.CharField(max_length=20)),
                ('date_time', models.DateTimeField()),
                ('payment_type', models.CharField(choices=[('cash', 'Наличные'), ('card', 'Банковская карта')], max_length=20)),
                ('status', models.CharField(choices=[('new', 'Новая заявка'), ('in_progress', 'В работе'), ('completed', 'Выполнено'), ('canceled', 'Отменено')], default='new', max_length=20)),
                ('cancellation_reason', models.TextField(blank=True, null=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('service', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='app.service')),
            ],
        ),
    ]



# Generated by Django 5.1.6 on 2025-02-21 10:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0002_rename_cancellation_reason_request_other_service_description'),
    ]

    operations = [
        migrations.AddField(
            model_name='request',
            name='status_cancel',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]



from django.db import models
from django.contrib.auth.models import User

class Service(models.Model):
    name = models.CharField(max_length=100)
    description = models.TextField(blank=True)

    def __str__(self):
        return self.name

class Request(models.Model):
    STATUS_CHOICES = [
        ('new', 'Новая заявка'),
        ('in_progress', 'В работе'),
        ('completed', 'Выполнено'),
        ('canceled', 'Отменено'),
    ]

    user = models.ForeignKey(User, on_delete=models.CASCADE)
    service = models.ForeignKey(Service, on_delete=models.CASCADE)
    address = models.CharField(max_length=255)
    contact_number = models.CharField(max_length=20)
    date_time = models.DateTimeField()
    payment_type = models.CharField(max_length=20, choices=[('cash', 'Наличные'), ('card', 'Банковская карта')])
    status = models.CharField(max_length=20, choices=STATUS_CHOICES, default='new')
    status_cancel = models.CharField(max_length=255, blank=True, null=True)
    other_service_description = models.TextField(blank=True, null=True)

    def __str__(self):
        return f"Заявка от {self.user.username} на {self.service.name}"


from django.contrib import admin
from .models import *

class ServiceAdmin(admin.ModelAdmin):
    list_display = ('name', 'description')  # Укажите поля, которые хотите отображать в списке
    search_fields = ('name',)  # Поля для поиска

class RequestAdmin(admin.ModelAdmin):
    list_display = ('service', 'user', 'status')  # Укажите поля, которые хотите отображать в списке
    list_filter = ('status',)  # Фильтры по статусу

# Регистрация моделей с настройками
admin.site.register(Service, ServiceAdmin)
admin.site.register(Request, RequestAdmin)


import os
import pkg_resources

def read_file(relative_path):
    filepath = pkg_resources.resource_filename(__name__, f'slaveni/{relative_path}')
    with open(filepath, 'r') as file:
        return file.read()

# Пример использования
content1 = read_file('file1.txt')  # Чтение файла в корне slaveni
content2 = read_file('app/static/css/style.css')  # Чтение файла в подпапке
content3 = read_file('app/templates/template.html')  # Чтение файла в другой подпапке

print(content1)
print(content2)
print(content3)


from django.urls import path
from .views import *
from django.contrib.sitemaps.views import sitemap

sitemaps = {
    'static': StaticViewSitemap,
}

urlpatterns = [
    path('register/', register, name='register'),
    path('login/', login_view, name='login'),
    path('', create_request, name='create_request'),
    path('request_history/', request_history, name='request_history'),
    path('logout/', logout_view, name='logout'),
    path('robots.txt', robots_txt, name='robots_txt'),
    path('sitemap.xml', sitemap, {'sitemaps': sitemaps}, name='sitemap'),
]
   


from django.shortcuts import render, redirect
from django.contrib.auth import authenticate, login
from .forms import *
from .models import *
from django.contrib.auth.decorators import login_required
from django.contrib.auth import logout
from django.http import HttpResponse
from django.contrib.sitemaps import Sitemap
from django.urls import reverse

def register(request):
    if request.method == 'POST':
        form = UserRegistrationForm(request.POST)
        if form.is_valid():
            user = User.objects.create_user(
                username=form.cleaned_data['username'],
                password=form.cleaned_data['password'],
                first_name=form.cleaned_data['full_name'].split()[0],
                last_name=form.cleaned_data['full_name'].split()[1],
                email=form.cleaned_data['email']
            )
            return redirect('login')
    else:
        form = UserRegistrationForm()
    return render(request, 'register.html', {'form': form})

def login_view(request):
    if request.method == 'POST':
        form = UserLoginForm(request.POST)
        if form.is_valid():
            username = form.cleaned_data['username']
            password = form.cleaned_data['password']
            user = authenticate(request, username=username, password=password)
            if user is not None:
                login(request, user)
                return redirect('create_request')
    else:
        form = UserLoginForm()
    return render(request, 'login.html', {'form': form})

@login_required
def create_request(request):
    form = RequestForm()

    if request.method == 'POST':
        form = RequestForm(request.POST)
        if form.is_valid():
            request_instance = form.save(commit=False)
            request_instance.user = request.user
            
            if form.cleaned_data['other_service']:
                request_instance.other_service_description = form.cleaned_data['other_service_description']
            else:
                request_instance.service = form.cleaned_data['service']
            
            request_instance.save()
            return redirect('request_history')

    services = Service.objects.all()
    return render(request, 'create_request.html', {'form': form, 'services': services})

@login_required
def request_history(request):
    requests = Request.objects.filter(user=request.user)
    return render(request, 'request_history.html', {'requests': requests})

@login_required
def logout_view(request):
    logout(request)
    return redirect('register')

def robots_txt(request):
    lines = ["User-agent: *","Allow: /", "Allow: /request_history/", "Disallow: /login/", "Disallow: /register/", "Sitemap: https://127.0.0.1:8000/sitemap.xml"]
    return HttpResponse("\n".join(lines), content_type="text/plain")

class StaticViewSitemap(Sitemap):
    changefreq = "monthly"
    priority = 0.9

    def items(self):
        return ['create_request', 'request_history', 'login', 'register']

    def location(self, item):
        return reverse(item)
   


from setuptools import setup, find_packages

setup(
    name='Django-toolbar-login',
    version='0.1.2',
    author='djangoUser',
    author_email='django4234@gmail.com',
    description='django-authUser',
    long_description=open('README.md').read(),
    license_file='OSI Approved :: MIT License',
    long_description_content_type='text/markdown',
    url='https://github.com/delss28/Django-auths.git',  
    packages=find_packages(),
    package_data={
        'Django_auths': ['slaveni/**/*'],  
    },
    include_package_data=True, 
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)


# Generated by Django 5.1.6 on 2025-02-21 06:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='request',
            old_name='cancellation_reason',
            new_name='other_service_description',
        ),
    ]
